@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2007 SWsoft. All rights reserved.
+ *  Copyright (C) 2000-2011, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ static inline void list_moveall(list_head_t *src, list_head_t *dst)
 }
 
 #define list_entry(ptr, type, field)					\
-	((type *)((char *)(ptr)-(unsigned long)(&((type *)0)->field)))
+	((type *)(void *)((char *)(ptr)-(unsigned long)(&((type *)0)->field)))
 
 #define list_first_entry(head, type, field)				\
 	list_entry((head)->next, type, field)
@@ -126,14 +126,15 @@ static inline void list_moveall(list_head_t *src, list_head_t *dst)
 
 char *list2str_c(char *name, char c, list_head_t *head);
 char *list2str(char *name, list_head_t *head);
-char **list2arg(list_head_t *head);
 int add_str_param(list_head_t *head, const char *str);
 int add_str_param2(list_head_t *head, char *str);
 int add_str2list(list_head_t *head, const char *val);
 void free_str_param(list_head_t *head);
 int copy_str_param(list_head_t *dst, list_head_t *src);
 char *find_str(list_head_t *head, const char *val);
+int __merge_str_list(int delall, list_head_t *old, list_head_t *add,
+	list_head_t *del, list_head_t *merged,
+	char* (*find_fn)(list_head_t*, const char*));
 int merge_str_list(int delall, list_head_t *old, list_head_t *add,
 	list_head_t *del, list_head_t *merged);
-int list_size(list_head_t *head);
 #endif /* _LIST_H_ */
