@@ -109,13 +109,15 @@ int vzctl_env_create_snapshot(vps_handler *h, envid_t veid,
 		logger(-1, 0, "Failed to store %s", tmp);
 		goto err;
 	}
-	// Store ve.conf
-	get_vps_conf_path(veid, fname, sizeof(fname));
-	vzctl_get_snapshot_ve_conf(fs->private, guid,
-			snap_ve_conf, sizeof(snap_ve_conf));
-	make_dir(snap_ve_conf, 0);
-	if (cp_file(snap_ve_conf, tmp))
-		goto err1;
+	if (!(param->flags & SNAPSHOT_SKIP_CONFIG)) {
+		// Store ve.conf
+		get_vps_conf_path(veid, fname, sizeof(fname));
+		vzctl_get_snapshot_ve_conf(fs->private, guid,
+				snap_ve_conf, sizeof(snap_ve_conf));
+		make_dir(snap_ve_conf, 0);
+		if (cp_file(snap_ve_conf, fname))
+			goto err1;
+	}
 
 	if (!(param->flags & SNAPSHOT_SKIP_SUSPEND))
 		run = vps_is_run(h, veid);
@@ -253,8 +255,8 @@ int vzctl_env_switch_snapshot(vps_handler *h, envid_t veid,
 	/* restore ve.conf */
 	vzctl_get_snapshot_ve_conf(fs->private, guid, fname, sizeof(fname));
 	if (stat_file(fname)) {
-		get_vps_conf_path(veid, fname, sizeof(fname) - 4);
-		strcat(fname, ".tmp");
+		get_vps_conf_path(veid, ve_conf_tmp, sizeof(ve_conf_tmp) - 4);
+		strcat(ve_conf_tmp, ".tmp");
 		if (cp_file(ve_conf_tmp, fname))
 			goto err2;
 	}
@@ -281,7 +283,7 @@ int vzctl_env_switch_snapshot(vps_handler *h, envid_t veid,
 		param = reread_vps_config(veid);
 		cpt.dumpfile = dumpfile;
 		if (vps_restore(h, veid, (param) ? param : g_p,
-					CMD_RESTORE, &cpt))
+					CMD_RESTORE, &cpt, SKIP_NONE))
 			logger(-1, 0, "Failed to resume Container");
 		free_vps_param(param);
 	}
